==> pandoc-citeproc-0.16.2-88-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.16.2
id: pandoc-citeproc-0.16.2-CboGMAtieImA2tpFFusPkw
key: pandoc-citeproc-0.16.2-CboGMAtieImA2tpFFusPkw
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane, Andrea Rossato
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.
    .
    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.
    .
    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.
category: Text
abi: cf6f6c1e75458465d79124ab010ecaff
exposed: True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.16.2-CboGMAtieImA2tpFFusPkw
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-0.7.1.1-1LPfbbioWzl7RPD13iVYcW directory-1.3.3.0
    filepath-1.4.2.1 hs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
    mtl-2.2.2 network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    pandoc-2.7.3-Jd79tKzZD15qovuVjXP3e
    pandoc-types-1.17.5.4-LNdrnkgX6YQJekilv3y447 parsec-3.1.13.0
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    split-0.2.3.3-IbK4kxLa0sUBqxIH6ONm60
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tagsoup-0.14.8-bQuTxVSfm0MHTKaVRPw4 text-1.2.3.1
    text-icu-0.7.0.1-JejFEKt5vpa5ez9tKsOTMT time-1.8.0.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    xml-conduit-1.8.0.1-4bEtXOFZ4ioD9TixoCXC7X
    yaml-0.11.1.0-8jFA6LZR6hejvB1XYns97
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-citeproc-0.16.2-91-x86_64.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.16.2
id: pandoc-citeproc-0.16.2-4JjparXIv1pLKDc99RQVSe
key: pandoc-citeproc-0.16.2-4JjparXIv1pLKDc99RQVSe
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane, Andrea Rossato
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.
    .
    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.
    .
    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.
category: Text
abi: c1aec4b352e22cf6f51f16cf42afb0f0
exposed: True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
import-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/pandoc-citeproc-0.16.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.16.2-4JjparXIv1pLKDc99RQVSe
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz directory-1.3.3.0
    filepath-1.4.2.1 hs-bibutils-6.7.0.0-FZxrSZg5Y3h1rDYhDXLOxx
    mtl-2.2.2 network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    pandoc-2.7.3-5SnTkUCJzxeIyZvuaUuhqe
    pandoc-types-1.17.5.4-B5Kl5AbfTZ7D5rhaKiMna8 parsec-3.1.13.0
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz
    split-0.2.3.3-IbK4kxLa0sUBqxIH6ONm60
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tagsoup-0.14.8-bQuTxVSfm0MHTKaVRPw4 text-1.2.3.1
    text-icu-0.7.0.1-JejFEKt5vpa5ez9tKsOTMT time-1.8.0.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    xml-conduit-1.8.0.1-EnaUWYjc4xzLlnqLPKrCm0
    yaml-0.11.1.0-LELoYugYmZc16IMCtvMYe4
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
